ResourceLoader class abstract

Resource loading strategy.

An abstraction of the functionality needed to load resources.

Implementations of this interface decide which URI schemes they support.

Constructors

ResourceLoader()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
openRead(Uri uri) → Stream<List<int>>
Reads the file located by uri as a stream of bytes.
parseUri(String s) → Uri
Parses s to Uri.
readAsBytes(Uri uri) → Future<List<int>>
Reads the file located by uri as a list of bytes.
readAsString(Uri uri, {Encoding? encoding}) → Future<String>
Reads the file located by uri as a String.
resolveUri(Uri uri) → Future<Uri>
Resolved uri to the actual Uri to load.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

defaultLoader → ResourceLoader
A resource loader that can load as many of the following URI schemes as are supported by the platform:
no setter